use 5.008;
use strict;
use warnings;

package Data::Conveyor::YAML::Marshall::Payload::Common;
BEGIN {
  $Data::Conveyor::YAML::Marshall::Payload::Common::VERSION = '1.101690';
}
# ABSTRACT: Stage-based conveyor-belt-like ticket handling system
use YAML::Marshall 'payload/common';
use parent 'Class::Scaffold::YAML::Marshall';

sub yaml_load {
    my $self         = shift;
    my $node         = $self->SUPER::yaml_load(@_);
    my $payload_item = $self->delegate->make_obj('payload_common');
    while (my ($key, $value) = each %$node) {
        $payload_item->$key($value);
    }
    $payload_item;
}
1;


__END__
=pod

=head1 NAME

Data::Conveyor::YAML::Marshall::Payload::Common - Stage-based conveyor-belt-like ticket handling system

=head1 VERSION

version 1.101690

=head1 METHODS

=head2 yaml_load

FIXME

=head1 INSTALLATION

See perlmodinstall for information and options on installing Perl modules.

=head1 BUGS AND LIMITATIONS

No bugs have been reported.

Please report any bugs or feature requests through the web interface at
L<http://rt.cpan.org>.

=head1 AVAILABILITY

The latest version of this module is available from the Comprehensive Perl
Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
site near you, or see
L<http://search.cpan.org/dist/Data-Conveyor/>.

The development version lives at
L<http://github.com/hanekomu/Data-Conveyor/>.
Instead of sending patches, please fork this project using the standard git
and github infrastructure.

=head1 AUTHORS

  Marcel Gruenauer <marcel@cpan.org>
  Florian Helmberger <fh@univie.ac.at>
  Achim Adam <ac@univie.ac.at>
  Mark Hofstetter <mh@univie.ac.at>
  Heinz Ekker <ek@univie.ac.at>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2004 by Marcel Gruenauer.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

